from .Kynegos_functions import *
from .Download_Catastro_Spain import *
from .Kynegos_GIS_functions import *
from .Kynegos_Easy_Plus_Functions import *

__version__ = "1.4.3"  # Define la versión directamente aquí
